package org.droid3d.io;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.HashMap;

import org.apache.log4j.Logger;
import org.droid3d.renderer.Bitmap;
import org.droid3d.utils.FileNameUtils;

public class BitmapFactory {
	private static final Logger		LOG			= Logger.getLogger(BitmapFactory.class);
	private static BitmapFactory	sInstance	= new BitmapFactory();

	public static BitmapFactory getInstance() {
		return sInstance;
	}

	private HashMap<String, BitmapDecoder>	mDecoder	= new HashMap<String, BitmapDecoder>();

	public BitmapDecoder getDecoder(String ext) {
		return mDecoder.get(ext);
	}

	public Bitmap load(File file) throws IOException {
		return load(file.toURI().toURL());
	}

	public Bitmap load(String resource) throws IOException {
		return load(getClass().getResource(resource));
	}

	public Bitmap load(URL url) throws IOException {
		Bitmap bitmap = null;
		if (url != null) {
			String ext = FileNameUtils.getFileExtension(url.toString());
			BitmapDecoder decoder = getDecoder(ext);
			if (decoder != null) {
				InputStream in = null;
				try {
					in = url.openStream();
					bitmap = decoder.decode(in);
				} finally {
					if (in != null) {
						in.close();
					}
				}
			}
		} // url != null
		return bitmap;
	}

	public void register(String ext, BitmapDecoder decoder) {
		mDecoder.put(ext, decoder);
	}
}
