/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.io;

import java.io.IOException;
import java.net.URL;
import java.util.HashMap;

import org.apache.log4j.Logger;
import org.droid3d.renderer.Font;
import org.droid3d.utils.FileNameUtils;

public class FontFactory {
	private static final Logger			LOG			= Logger.getLogger(FontFactory.class);

	private static final FontFactory	sInstance	= new FontFactory();

	public static FontFactory getInstance() {
		return sInstance;
	}

	private HashMap<String, FontLoader>	mFontLoader	= new HashMap<String, FontLoader>();

	public Font load(URL url) throws IOException {
		Font font = null;
		String ext = FileNameUtils.getFileExtension(url.toString());
		FontLoader loader = mFontLoader.get(ext);
		if (loader != null) {
			font = loader.load(url);
		}
		return font;
	}

	public void register(String fileExtension, FontLoader loader) {
		mFontLoader.put(fileExtension, loader);
	}
}
