/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.math;

/**
 *
 */
public class Double3 {
	public static Double3 add(Double3 r, Double3 l) {
		Double3 tmp = new Double3(r);
		return tmp.add(l);
	}

	/**
	 * Calculates the cross product of vectors.
	 * 
	 * @param r
	 * @param l
	 * @return
	 */
	public static Double3 cross(Double3 r, Double3 l) {
		Double3 tmp = new Double3(r);
		return tmp.cross(l);
	}

	public static Double3 mult(Double3 v, double f) {
		Double3 tmp = new Double3(v);
		return tmp.mult(f);
	}

	public static Double3 normalize(Double3 v) {
		Double3 normalized = new Double3(v);
		normalized.normalize();
		return normalized;
	}

	public static Double3 sub(Double3 r, Double3 l) {
		Double3 tmp = new Double3(r);
		return tmp.sub(l);
	}

	public double	x	= 0f;
	public double	y	= 0f;
	public double	z	= 0f;

	public Double3() {
		x = y = z = 0f;
	}

	public Double3(double x, double y, double z) {
		this.x = x;
		this.y = y;
		this.z = z;
	}

	public Double3(double[] array) {
		load(array);
	}

	/**
	 * Creates a vector that is a copy of src.
	 * 
	 * @param src
	 */
	public Double3(Double3 src) {
		load(src);
	}

	public Double3 add(Double3 v) {
		x += v.x;
		y += v.y;
		z += v.z;

		return this;
	}

	public double angle(Double3 v) {
		double c = dot(v) / (getLength() * v.getLength());
		return Math.acos(c);
	}

	public Double3 cross(Double3 v) {
		double cx = y * v.z - v.y * z;
		double cy = z * v.x - v.z * x;
		double cz = x * v.y - v.x * y;

		x = cx;
		y = cy;
		z = cz;

		return this;
	}

	public double dot(Double3 v) {
		return x * v.x + y * v.y + z * v.z;
	}

	public double getLength() {
		return Math.sqrt(getSquaredLength());
	}

	public double getSquaredLength() {
		return x * x + y * y + z * z;
	}

	public Double3 load(double vx, double vy, double vz) {
		x = vx;
		y = vy;
		z = vz;
		return this;
	}

	public Double3 load(double[] array) {
		x = array[0];
		y = array[1];
		z = array[2];
		return this;
	}

	public Double3 load(Double3 v) {
		x = v.x;
		y = v.y;
		z = v.z;
		return this;
	}

	public Double3 mult(double f) {
		x *= f;
		y *= f;
		z *= f;
		return this;
	}

	public Double3 normalize() {
		double rpl = 1f / getLength();
		return mult(rpl);
	}

	public Double3 sub(Double3 v) {
		x -= v.x;
		y -= v.y;
		z -= v.z;

		return this;
	}

	public double[] toArray() {
		return toArray(new double[3]);
	}

	public double[] toArray(double[] array) {
		array[0] = x;
		array[1] = y;
		array[2] = z;
		return array;
	}
}
