/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.math;

import com.google.common.reflect.TypeToken;

public class Float2 {
	public static final TypeToken<Float2>	TYPE_TOKEN	= TypeToken.of(Float2.class);

	public static Float2 add(Float2 r, Float2 l) {
		Float2 tmp = new Float2(r);
		return tmp.add(l);
	}

	public static Float2 mult(Float2 v, float f) {
		Float2 tmp = new Float2(v);
		return tmp.mult(f);
	}

	public static Float2 sub(Float2 r, Float2 l) {
		Float2 tmp = new Float2(r);
		return tmp.sub(l);
	}

	public float	x;
	public float	y;

	public Float2() {
		x = 0f;
		y = 0f;
	}

	public Float2(float s, float t) {
		x = s;
		y = t;
	}

	public Float2(float[] v) {
		load(v);
	}

	public Float2(Float2 v) {
		load(v);
	}

	public Float2 add(Float2 v) {
		x += v.x;
		y += v.y;
		return this;

	}

	public Float2 load(float[] v) {
		x = v[0];
		y = v[1];
		return this;
	}

	public Float2 load(Float2 v) {
		x = v.x;
		y = v.y;
		return this;
	}

	public Float2 mult(float f) {
		x *= f;
		y *= f;
		return this;
	}

	public Float2 sub(Float2 v) {
		x -= v.x;
		y -= v.y;
		return this;
	}
}
