/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.math;

/**
 *
 */
public class Float3 {
	public static Float3 add(Float3 r, Float3 l) {
		Float3 tmp = new Float3(r);
		return tmp.add(l);
	}

	/**
	 * Calculates the cross product of vectors.
	 * 
	 * @param r
	 * @param l
	 * @return
	 */
	public static Float3 cross(Float3 r, Float3 l) {
		Float3 tmp = new Float3(r);
		return tmp.cross(l);
	}

	public static Float3 mult(Float3 v, float f) {
		Float3 tmp = new Float3(v);
		return tmp.mult(f);
	}

	public static Float3 normalize(Float3 v) {
		Float3 normalized = new Float3(v);
		normalized.normalize();
		return normalized;
	}

	public static Float3 sub(Float3 r, Float3 l) {
		Float3 tmp = new Float3(r);
		return tmp.sub(l);
	}

	public float	x	= 0f;
	public float	y	= 0f;
	public float	z	= 0f;

	public Float3() {
		x = y = z = 0f;
	}

	public Float3(float x, float y, float z) {
		this.x = x;
		this.y = y;
		this.z = z;
	}

	public Float3(float[] array) {
		load(array);
	}

	/**
	 * Creates a vector that is a copy of src.
	 * 
	 * @param src
	 */
	public Float3(Float3 src) {
		load(src);
	}

	public Float3 add(Float3 v) {
		x += v.x;
		y += v.y;
		z += v.z;

		return this;
	}

	public float angle(Float3 v) {
		float c = dot(v) / (getLength() * v.getLength());
		return (float) Math.acos(c);
	}

	public Float3 cross(Float3 v) {
		float cx = y * v.z - v.y * z;
		float cy = z * v.x - v.z * x;
		float cz = x * v.y - v.x * y;

		x = cx;
		y = cy;
		z = cz;

		return this;
	}

	public float dot(Float3 v) {
		return x * v.x + y * v.y + z * v.z;
	}

	public float getLength() {
		return (float) Math.sqrt(getSquaredLength());
	}

	public float getSquaredLength() {
		return x * x + y * y + z * z;
	}

	public Float3 load(float vx, float vy, float vz) {
		x = vx;
		y = vy;
		z = vz;
		return this;
	}

	public Float3 load(float[] array) {
		x = array[0];
		y = array[1];
		z = array[2];
		return this;
	}

	public Float3 load(Float3 v) {
		x = v.x;
		y = v.y;
		z = v.z;
		return this;
	}

	public Float3 mult(float f) {
		x *= f;
		y *= f;
		z *= f;
		return this;
	}

	public Float3 normalize() {
		float rpl = 1f / getLength();
		return mult(rpl);
	}

	public void set(float x, float y, float z) {
		this.x = x;
		this.y = y;
		this.z = z;
	}

	public Float3 sub(Float3 v) {
		x -= v.x;
		y -= v.y;
		z -= v.z;

		return this;
	}

	public float[] toArray() {
		return toArray(new float[3]);
	}

	public float[] toArray(float[] array) {
		array[0] = x;
		array[1] = y;
		array[2] = z;
		return array;
	}
}
