/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.math;

public class Float4 {

	public static Float4 add(Float4 r, Float4 l)
	{
		Float4 tmp = new Float4(r);
		return tmp.add(l);
	}

	public static Float4 mult(Float4 v, float f)
	{
		Float4 tmp = new Float4(v);
		return tmp.mult(f);
	}

	public static Float4 sub(Float4 r, Float4 l)
	{
		Float4 tmp = new Float4(r);
		return tmp.sub(l);
	}

	public float	x	= 0f;
	public float	y	= 0f;
	public float	z	= 0f;
	public float	w	= 0f;

	public Float4()
	{

	}

	public Float4(float[] tmp)
	{
		x = tmp[0];
		y = tmp[1];
		z = tmp[2];
		w = tmp[3];
	}

	public Float4(Float4 v)
	{
		load(v);
	}

	public Float4 add(Float4 v)
	{
		x += v.x;
		y += v.y;
		z += v.z;
		w += v.w;
		return this;
	}

	public float dot(Float4 v)
	{
		return x * v.x + y * v.y + z * v.z + w * v.w;
	}

	public float getLength()
	{
		return (float) Math.sqrt(getSquaredLength());
	}

	public float getSquaredLength()
	{
		return x * x + y * y + z * z + w * w;
	}

	public Float4 load(Float4 v)
	{
		x = v.x;
		y = v.y;
		z = v.z;
		w = v.w;
		return this;
	}

	public Float4 mult(float f)
	{
		x *= f;
		y *= f;
		z *= f;
		w *= f;
		return this;
	}

	public Float4 sub(Float4 v)
	{
		x -= v.x;
		y -= v.y;
		z -= v.z;
		w -= v.w;
		return this;
	}
}
