/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.math;

/**
 * A matrix.
 */
public class Matrix {
	/**
	 * values of the matrix
	 */
	protected float[]	mat;

	private int			mRowCount;
	private int			mColumnCount;

	/**
	 * Creates a matrix.
	 * 
	 * @param rows
	 *            number of rows
	 * @param cols
	 *            number of columns
	 */
	public Matrix(int rows, int cols) {
		mRowCount = rows;
		mColumnCount = cols;
		mat = new float[mRowCount * mColumnCount];
	}

	/**
	 * Creates a matrix that is a copy of src.
	 * 
	 * @param src
	 *            The matrix to copy into this matrix
	 */
	public Matrix(Matrix src) {
		mRowCount = src.mRowCount;
		mColumnCount = src.mColumnCount;
		mat = new float[mRowCount * mColumnCount];
	}

	/**
	 * Returns the value of the matrix at row, col.
	 * 
	 * @param row
	 * @param col
	 * @return
	 */
	public float get(int row, int col) {
		return mat[col * mRowCount + row];
	}

	public float[] getArray() {
		return mat;
	}

	public float[] getColumn(int column) {
		float[] c = new float[mRowCount];
		for (int row = 0; row < mRowCount; row++) {
			c[row] = mat[column * mRowCount + row];
		}
		return c;
	}

	/**
	 * Returns the number of columns.
	 * 
	 * @return
	 */
	public int getColumnCount() {
		return mColumnCount;
	}

	/**
	 * Returns a row of the matrix.
	 * 
	 * @param row
	 * @return
	 */
	public float[] getRow(int row) {
		float[] r = new float[mColumnCount];
		for (int col = 0; col < mColumnCount; col++) {
			r[col] = mat[col * mRowCount + row];
		}
		return r;
	}

	/**
	 * @return
	 */
	public int getRowCount() {
		return mRowCount;
	}

	public void load(float[] m) {
		System.arraycopy(m, 0, mat, 0, mRowCount * mColumnCount);
	}

	public Matrix set(int row, int col, float v) {
		mat[col * mRowCount + row] = v;
		return this;
	}

	public Matrix transpose() {
		float[] tmpMat = new float[mRowCount * mColumnCount];
		for (int col = 0; col < mColumnCount; col++) {
			for (int row = 0; row < mRowCount; row++) {
				tmpMat[col * mColumnCount + row] = mat[col * mRowCount + row];
			}
		}
		load(tmpMat);
		int tmp = mColumnCount;
		mColumnCount = mRowCount;
		mRowCount = tmp;
		return this;
	}

}
