/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.math;

public class Matrix33 extends SqrMatrix {
	public static Matrix33 add(Matrix33 r, Matrix33 l)
	{
		Matrix33 tmp = new Matrix33(r);
		return tmp.add(l);
	}

	public static Matrix33 mult(Matrix33 m, float f)
	{
		Matrix33 tmp = new Matrix33(m);
		return tmp.mult(f);
	}

	public static Matrix33 mult(Matrix33 r, Matrix33 l)
	{
		Matrix33 tmp = new Matrix33(r);
		return tmp.mult(l);
	}

	public static Matrix33 sub(Matrix33 r, Matrix33 l)
	{
		Matrix33 tmp = new Matrix33(r);
		return tmp.sub(l);
	}

	public Matrix33()
	{
		super(3);
	}

	public Matrix33(Matrix33 m)
	{
		super(3);
		load(m);
	}

	public Matrix33 add(Matrix33 m)
	{
		for (int i = 0; i < 9; i++) {
			mat[i] += m.mat[i];
		}
		identity = false;
		return this;
	}

	public void load(Matrix33 m)
	{
		System.arraycopy(m.mat, 0, mat, 0, 9);
		identity = m.identity;
	}

	public Matrix33 mult(float f)
	{
		for (int i = 0; i < 9; i++) {
			mat[i] *= f;
		}
		identity = false;
		return this;
	}

	public Matrix33 mult(Matrix33 v)
	{
		if (v.identity) {
			return this;
		}

		if (identity) {
			load(v);
			return this;
		}

		float[] p = new float[9];

		p[0] = mat[0] * v.mat[0] + mat[3] * v.mat[1] + mat[6] * v.mat[2];
		p[1] = mat[1] * v.mat[0] + mat[4] * v.mat[1] + mat[7] * v.mat[2];
		p[2] = mat[2] * v.mat[0] + mat[6] * v.mat[1] + mat[8] * v.mat[2];

		p[3] = mat[0] * v.mat[3] + mat[3] * v.mat[4] + mat[6] * v.mat[5];
		p[4] = mat[1] * v.mat[3] + mat[4] * v.mat[4] + mat[7] * v.mat[5];
		p[5] = mat[2] * v.mat[3] + mat[6] * v.mat[4] + mat[8] * v.mat[5];

		p[6] = mat[0] * v.mat[6] + mat[3] * v.mat[7] + mat[6] * v.mat[8];
		p[7] = mat[1] * v.mat[6] + mat[4] * v.mat[7] + mat[7] * v.mat[8];
		p[8] = mat[2] * v.mat[6] + mat[6] * v.mat[7] + mat[8] * v.mat[8];

		System.arraycopy(p, 0, mat, 0, 9);
		identity = false;

		return this;
	}

	public Float3 mult(Float3 v)
	{
		if (identity) {
			return new Float3(v);
		}

		Float3 p = new Float3();
		p.x = mat[0] * v.x + mat[3] * v.y + mat[6] * v.z;
		p.y = mat[1] * v.x + mat[4] * v.y + mat[7] * v.z;
		p.z = mat[2] * v.x + mat[5] * v.y + mat[8] * v.z;
		return p;
	}

	public Matrix33 sub(Matrix33 m)
	{
		for (int i = 0; i < 9; i++) {
			mat[i] -= m.mat[i];
		}
		identity = false;
		return this;
	}
}
