/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.math;

/**
 * A square matrix.
 */
public class SqrMatrix extends Matrix {
	protected boolean	identity	= false;

	public SqrMatrix(int size)
	{
		super(size, size);
	}

	public boolean isIdentity()
	{
		return identity;
	}

	@Override
	public void load(float[] m)
	{
		super.load(m);
		identity = false;
	}

	public SqrMatrix loadIdentity()
	{
		for (int col = 0; col < getColumnCount(); col++) {
			for (int row = 0; row < getRowCount(); row++) {
				set(row, col, row == col ? 1f : 0f);
			}
		}
		identity = true;
		return this;
	}

	@Override
	public SqrMatrix set(int row, int col, float v)
	{
		super.set(row, col, v);
		identity = false;
		return this;
	}

	@Override
	public SqrMatrix transpose()
	{
		super.transpose();
		identity = false;
		return this;
	}

}
