package org.droid3d.renderer;

import java.nio.ByteBuffer;

import org.droid3d.utils.Type;

public class Bitmap {
	public static class Builder {
		private int			mWidth;
		private int			mHeight;
		private Format		mFormat;
		private Type		mDataType;
		private ByteBuffer	mData;

		public Bitmap build() {
			Bitmap bitmap = new Bitmap();

			bitmap.mHeight = mHeight;
			bitmap.mWidth = mWidth;
			bitmap.mFormat = mFormat;
			bitmap.mDataType = mDataType;
			bitmap.mData = mData;

			return bitmap;
		}

		public Builder setData(byte[] data) {
			mData = ByteBuffer.wrap(data);
			return this;
		}

		public Builder setData(ByteBuffer data) {
			mData = data;
			return this;
		}

		public Builder setDataType(Type dataType) {
			mDataType = dataType;
			return this;
		}

		public Builder setFormat(Format format) {
			mFormat = format;
			return this;
		}

		public Builder setHeight(int height) {
			mHeight = height;
			return this;
		}

		public Builder setWidth(int width) {
			mWidth = width;
			return this;
		}
	}

	public enum Format {
		RGB, RGBA;
	}

	private int			mWidth;
	private int			mHeight;
	private Format		mFormat;
	private Type		mDataType;
	private ByteBuffer	mData;

	public int getByteCount() {
		return mData.capacity();
	}

	public ByteBuffer getData() {
		return mData;
	}

	public Type getDataType() {
		return mDataType;
	}

	public Format getFormat() {
		return mFormat;
	}

	public int getHeight() {
		return mHeight;
	}

	public int getWidth() {
		return mWidth;
	}

}
