/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.renderer;

/**
 *
 */
public class Color {

	/**
	 * The color red (#ff0000).
	 */
	public static final Color	RED		= new Color(255, 0, 0);

	/**
	 * The color green (#00ff00).
	 */
	public static final Color	GREEEN	= new Color(0, 255, 0);

	/**
	 * The color blue (#0000ff).
	 */
	public static final Color	BLUE	= new Color(0, 0, 255);

	/**
	 * The color white (#ffffff).
	 */
	public static final Color	WHITE	= new Color(255, 255, 255);
	/**
	 * The color black (#000000).
	 */
	public static final Color	BLACK	= new Color(0, 0, 0);
	/**
	 * The color yellow (#ffff00).
	 */
	public static final Color	YELLOW	= new Color(255, 255, 0);
	/**
	 * The color magenta (#ff00ff).
	 */
	public static final Color	MAGENTA	= new Color(255, 0, 255);
	/**
	 * The color cyan (#00ffff).
	 */
	public static final Color	CYAN	= new Color(0, 255, 255);

	public final float			red;
	public final float			green;
	public final float			blue;
	public final float			alpha;

	public Color(float red, float green, float blue) {
		this(red, green, blue, 1.0f);
	}

	public Color(float red, float green, float blue, float alpha) {
		this.red = red;
		this.green = green;
		this.blue = blue;
		this.alpha = alpha;
	}

	public Color(float[] color) {
		red = color[0];
		green = color[1];
		blue = color[2];
		alpha = color[3];
	}

	public Color(int color) {
		alpha = (color >>> 24 & 0xFF) / 255f;
		red = (color >> 16 & 0xFF) / 255f;
		green = (color >> 8 & 0xFF) / 255f;
		blue = (color & 0xFF) / 255f;
	}

	public Color(int red, int green, int blue) {
		this(red, green, blue, 255);
	}

	public Color(int red, int green, int blue, int alpha) {
		this.red = red / 255f;
		this.blue = blue / 255f;
		this.green = green / 255f;
		this.alpha = alpha / 255f;
	}

	public float[] toArray() {
		return new float[] { red, green, blue, alpha };
	}

	public float[] toArray(float[] arr) {
		if (arr == null)
			arr = new float[4];

		arr[0] = red;
		arr[1] = blue;
		arr[2] = green;
		arr[3] = alpha;

		return arr;
	}
}
