/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.renderer;

import java.util.Map;

import org.droid3d.math.Float2;

public class Font {

	public static class Glyph {
		public int			x;
		public int			y;
		public int			width;
		public int			height;
		public int			xadvance;
		public int[]		offset	= new int[2];
		public Float2[]	uvs		= new Float2[4];
	}

	private Texture					mTexture;
	private Map<Character, Glyph>	mGlyphs;
	private int						mLineHeight;
	private int						mBaseLine;

	public Font(int lineHeight, int base, Texture texture,
			Map<Character, Glyph> glyphs) {
		mLineHeight = lineHeight;
		mBaseLine = base;
		mTexture = texture;
		mGlyphs = glyphs;
	}

	public int getBaseLine() {
		return mBaseLine;
	}

	public Glyph getGlyph(char c) {
		return mGlyphs.get(c);
	}

	public int getLineHeight() {
		return mLineHeight;
	}

	public Texture getTexture() {
		return mTexture;
	}

}
