package org.droid3d.renderer;

import org.droid3d.math.Float3;
import org.droid3d.math.MathF;

public class Light {
	public enum Type {
		POINT, SPOT, DIRECTIONAL;
	}

	public static final Color	DEFAULT_SPECULAR_COLOR	= Color.WHITE;
	public static final Color	DEFAULT_DIFFUSE_COLOR	= Color.WHITE;
	public static final Color	DEFAULT_AMBIENT_COLOR	= Color.BLACK;

	public static final Float3	DEFAULT_POSITION		= new Float3(0f, 0f, 0f);
	public static final Float3	DEFAULT_DIRECTION		= new Float3(0f, 0f, 1f);

	private final Type			mType;
	private Color				mAmbientColor			= DEFAULT_AMBIENT_COLOR;
	private Color				mDiffuseColor			= DEFAULT_DIFFUSE_COLOR;
	private Color				mSpecularColor			= DEFAULT_SPECULAR_COLOR;

	private Float3				mPosition				= DEFAULT_POSITION;
	private Float3				mDirection				= DEFAULT_DIRECTION;

	float						mAngle					= MathF.PI;

	float						mExponent;

	boolean						mEnabled				= true;

	public Light(Type type) {
		mType = type;
	}

	public Color getAmbientColor() {
		return mAmbientColor;
	}

	public float getAngle() {
		return mAngle;
	}

	public Color getColor() {
		return mDiffuseColor;
	}

	public Color getDiffuseColor() {
		return mDiffuseColor;
	}

	public Float3 getDirection() {
		return mDirection;
	}

	public float getExponent() {
		return mExponent;
	}

	public Float3 getPosition() {
		return mPosition;
	}

	public Color getSpecularColor() {
		return mSpecularColor;
	}

	public Type getType() {
		return mType;
	}

	public boolean isEnabled() {
		return mEnabled;
	}

	public void setAmbientColor(Color ambientColor) {
		mAmbientColor = ambientColor;
	}

	public void setAngle(float angle) {
		mAngle = angle;
	}

	public void setColor(Color color) {
		mDiffuseColor = color;
	}

	public void setDiffuseColor(Color diffuseColor) {
		mDiffuseColor = diffuseColor;
	}

	public void setDirection(Float3 direction) {
		mDirection = direction;
	}

	public void setEnabled(boolean enabled) {
		mEnabled = enabled;
	}

	public void setExponent(float exponent) {
		mExponent = exponent;
	}

	public void setPosition(Float3 position) {
		mPosition = position;
	}

	public void setSpecularColor(Color specularColor) {
		mSpecularColor = specularColor;
	}

}
