package org.droid3d.renderer;

import org.droid3d.renderer.Material.BlendMode;
import org.droid3d.renderer.buffer.Buffer;
import org.droid3d.renderer.buffer.IndexBuffer;
import org.droid3d.renderer.buffer.VertexBuffer;
import org.droid3d.renderer.shader.Shader;

interface Pipeline {
	void bindIndexBuffer(int handle);

	void bindTexture(int handle, BlendMode mode, int unit);

	void bindVertexBuffer(int handle);

	void bufferData(int target, Buffer buffer);

	int compileShader(Shader shader);

	/**
	 * Create a handle to a buffer in video memory.
	 * 
	 * @return handle to the buffer
	 */
	int createBuffer();

	/**
	 * Create a handle to a shader in video memory.
	 * 
	 * @param type
	 * @return
	 */
	int createShader(Shader.Type type);

	/**
	 * Create a handle to a shader program in video memory.
	 * 
	 * @return
	 */
	int createShaderProgram();

	/**
	 * Create a handle to a texture in video memory.
	 * 
	 * @return handle to the texture
	 */
	int createTexture();

	void deleteBuffer(int handle);

	void deleteShader(int handle);

	void deleteShaderProgram(int handle);

	void deleteTexture(int handle);

	void enableShaderProgram(int handle);

	int linkShaderProgram(int... shader);

	void update(Buffer buffer, int handle, int target);

	void updateIndexBuffer(IndexBuffer buffer, int handle);

	void updateVertexBuffer(VertexBuffer buffer, int handle);

	int uploadIndexBuffer(IndexBuffer buffer);

	int uploadTexture(Texture texture);

	int uploadVertexBuffer(VertexBuffer buffer);
}
