/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.renderer;

/**
 * RenderStatistics are used by the {@link Renderer} to keep track of render
 * statistics.
 */
public class RenderStatistics {
	public int	vboCount			= 0;
	public int	iboCount			= 0;

	public long	vboSize				= 0;
	public long	iboSize				= 0;

	public int	frameNumber			= 0;
	public int	drawCalls			= 0;

	public int	shaderCount			= 0;
	public int	shaderProgramCount	= 0;

	public int	textureCount		= 0;
	public long	textureSize			= 0;

	/**
	 * Returns the number of draw calls (glDrawElements) issued by the renderer
	 * in the current frame.
	 * 
	 * @return number of draw calls in the current frame
	 */
	public int getDrawCalls() {
		return drawCalls;
	}

	/**
	 * Returns the number of the frame that is rendered.
	 * 
	 * @return number of the frame that is rendered
	 */
	public int getFrameNumber() {
		return frameNumber;
	}

	/**
	 * Returns the number of IBOs created by the renderer.
	 * 
	 * @return number of IBOs create by the renderer
	 */
	public int getIBOCount() {
		return iboCount;
	}

	/**
	 * Returns the size of the IBOs created by the renderer.
	 * 
	 * @return size of the IBOs created by the render in bytes
	 */
	public long getIBOSize() {
		return iboSize;
	}

	/**
	 * Get the number of shaders used by the renderer.
	 * 
	 * @return
	 */
	public int getShaderCount() {
		return shaderCount;
	}

	/**
	 * Get the number of textures used by the renderer.
	 * 
	 * @return
	 */
	public int getTextureCount() {
		return textureCount;
	}

	/**
	 * Get the size of the textures used by the renderer.
	 * 
	 * @return size in bytes
	 */
	public long getTextureSize() {
		return textureSize;
	}

	/**
	 * Returns the number of VBOs created by the renderer.
	 * 
	 * @return number of VBOs create by the renderer
	 */
	public int getVBOCount() {
		return vboCount;
	}

	/**
	 * Returns the size of the VBOs created by the renderer.
	 * 
	 * @return size of the VBOs created by the render in bytes
	 */
	public long getVBOSize() {
		return vboSize;
	}
}
