/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.renderer;

public class Texture {
	public enum Filter {
		LINEAR;
	}

	public enum Wrap {
		REPEAT;
	}

	private Bitmap	mBitmap;

	private Filter	mMinFilter	= Filter.LINEAR;
	private Filter	mMagFilter	= Filter.LINEAR;

	private Wrap	mWrapS		= Wrap.REPEAT;
	private Wrap	mWrapT		= Wrap.REPEAT;

	public Texture(Bitmap bitmap) {
		mBitmap = bitmap;
	}

	public Bitmap getBitmap() {
		return mBitmap;
	}

	public int getHeight() {
		return mBitmap.getHeight();
	}

	public Filter getMagFilter() {
		return mMagFilter;
	}

	public Filter getMinFilter() {
		return mMinFilter;
	}

	public long getSize() {
		// TODO Auto-generated method stub
		return mBitmap == null ? 0 : mBitmap.getByteCount();
	}

	public int getWidth() {
		return mBitmap.getWidth();
	}

	public Wrap getWrapS() {
		return mWrapS;
	}

	public Wrap getWrapT() {
		return mWrapT;
	}

	public void setMagFilter(Filter pMagFilter) {
		mMagFilter = pMagFilter;
	}

	public void setMinFilter(Filter pMinFilter) {
		mMinFilter = pMinFilter;
	}

	public void setWrapS(Wrap pWrapS) {
		mWrapS = pWrapS;
	}

	public void setWrapT(Wrap pWrapT) {
		mWrapT = pWrapT;
	}

}
