/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.renderer.buffer;

/**
 * A buffer to store vertex indices.
 */
public class IndexBuffer extends Buffer {

	private int	mIndexCount;

	/**
	 * Create an IndexBuffer.
	 * 
	 * @param indexCount
	 *            number of indices
	 */
	public IndexBuffer(int indexCount) {
		this(indexCount, Usage.STATIC);
	}

	/**
	 * Create an IndexBuffer.
	 * 
	 * @param indexCount
	 * @param usage
	 */
	public IndexBuffer(int indexCount, Usage usage) {
		super(indexCount * org.droid3d.utils.Type.SHORT.size(), Buffer.Type.INDEX_BUFFER, usage);
		mIndexCount = indexCount;
	}

	/**
	 * Create an IndexBuffer.
	 * 
	 * @param indices
	 */
	public IndexBuffer(short[] indices) {
		this(indices, Usage.STATIC);
	}

	/**
	 * Create an IndexBuffer.
	 * 
	 * @param indices
	 * @param usage
	 */
	public IndexBuffer(short[] indices, Usage usage) {
		super(indices.length * org.droid3d.utils.Type.SHORT.size(), Buffer.Type.INDEX_BUFFER, usage);
		mIndexCount = indices.length;
		putShort(0, indices);
	}

	public void add(short index) {
		getData().putShort(index);
	}

	/**
	 * Get an index.
	 * 
	 * @param i
	 * @return
	 */
	public short getIndex(int i) {
		return getShort(i * org.droid3d.utils.Type.SHORT.size());
	}

	/**
	 * Get the number of indices.
	 * 
	 * @return
	 */
	public int getIndexCount() {
		return mIndexCount;
	}

	/**
	 * Set an index.
	 * 
	 * @param i
	 * @param index
	 */
	public void setIndex(int i, short... index) {
		putShort(i * org.droid3d.utils.Type.SHORT.size(), index);
	}

	/**
	 * Get the content of the index buffer.
	 * 
	 * @return
	 */
	public short[] toArray() {
		return getShort(0, mIndexCount);
	}
}
