package org.droid3d.scenegraph;

import java.util.LinkedList;
import java.util.List;
import java.util.Map;

import org.droid3d.renderer.Light;
import org.droid3d.renderer.Material;
import org.droid3d.renderer.Mesh;
import org.droid3d.renderer.states.RenderState;
import org.droid3d.renderer.states.RenderState.Type;
import org.droid3d.utils.BoundingVolumes;

public class Geometry extends LeafNode {
	private Mesh			mMesh;
	private Material		mMaterial;
	private BoundingVolume	mMeshBound	= new BoundingVolume();

	protected Geometry() {
	}

	public Geometry(Mesh mesh, Material material) {
		mMesh = mesh;
		mMaterial = material;
		updateBound();
	}

	@Override
	public void cull(Culler culler, boolean doCull) {
		culler.insert(this);
	}

	public final Material getMaterial() {
		return mMaterial;
	}

	public final Mesh getMesh() {
		return mMesh;
	}

	public void setMaterial(Material material) {
		mMaterial = material;
	}

	public void setMesh(Mesh mesh) {
		mMesh = mesh;
	}

	public void updateBound() {
		mMeshBound.load(BoundingVolumes.computeFrom(mMesh.getVertexBuffer()));
	}

	@Override
	public void updateBoundingVolume() {
		setBoundingVolume(mMeshBound.transform(getWorldTransformation()));
	}

	@Override
	protected void updateState(Map<Type, LinkedList<RenderState>> stateStacks, LinkedList<Light> lightStack) {
		for (RenderState.Type type : RenderState.Type.values()) {
			LinkedList<RenderState> stack = stateStacks.get(type);
			addState(stack.peekLast());
		}

		List<Light> lights = getLights();
		lights.clear();
		for (Light l : lightStack) {
			lights.add(l);
		}
	}
}
