/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.scenegraph;

import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

import org.droid3d.renderer.Light;
import org.droid3d.renderer.states.RenderState;
import org.droid3d.renderer.states.RenderState.Type;

/**
 * A scenegraph node.
 */
public class GroupNode extends Node {
	private List<Node>	mChildren	= new ArrayList<Node>();

	/**
	 * Add a child.
	 * 
	 * @param child
	 */
	public void addChild(Node child) {
		assert child != null && child.getParent() == null;
		mChildren.add(child);
		child.setParent(this);
	}

	@Override
	public void cull(Culler culler, boolean doCull) {
		for (int i = 0; i < mChildren.size(); i++) {
			Node child = mChildren.get(i);
			if (child != null) {
				child.onCull(culler, doCull);
			}
		}
	}

	/**
	 * Get the number of children.
	 * 
	 * @return
	 */
	public int getChildCount() {
		return mChildren.size();
	}

	/**
	 * Remove a child.
	 * 
	 * @param child
	 */
	public void removeChild(Node child) {
		mChildren.remove(child);
		child.setParent(null);
	}

	@Override
	public void updateBoundingVolume() {
		if (!worldBoundIsCurrent && mChildren.size() > 0) {
			getBoundingVolume().load(mChildren.get(0).getBoundingVolume());

			for (int i = 1; i < mChildren.size(); i++) {
				Node child = mChildren.get(i);
				getBoundingVolume().merge(child.getBoundingVolume());
			}
		}
	}

	@Override
	protected void updateState(Map<Type, LinkedList<RenderState>> stateStacks, LinkedList<Light> lightStack) {
		for (Node child : mChildren) {
			if (child != null) {
				child.updateRS(stateStacks, lightStack);
			}
		}
	}

	@Override
	protected void updateWorldData(float time) {
		super.updateWorldData(time);

		for (int i = 0; i < mChildren.size(); i++) {
			Node child = mChildren.get(i);
			if (child != null) {
				child.updateGS(time, false);
			}
		}
	}
}
