/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.scenegraph;

import java.util.ArrayList;
import java.util.List;

public class SceneObject {
	public interface Controller {
		public boolean onUpdate(float time);
	}

	private String					mName;
	private final List<Controller>	mControllers	= new ArrayList<Controller>();

	protected SceneObject() {

	}

	public void addController(Controller controller) {
		mControllers.add(controller);
	}

	public int getControllerCount() {
		return mControllers.size();
	}

	public String getName() {
		return mName;
	}

	public boolean onGetVisibleUpdateControllers(final Camera camera) {
		return true;
	}

	public void removeAllControllers() {
		mControllers.clear();
	}

	public void removeController(Controller controller) {
		mControllers.remove(controller);
	}

	public void setName(String name) {
		mName = name;
	}

	@Override
	public String toString() {
		return mName != null ? mName : super.toString();
	}

	public boolean updateControllers(float time) {
		for (Controller controller : mControllers) {
			if (!controller.onUpdate(time)) {
				return false;
			}
		}
		return true;
	}

}
