package org.droid3d.utils;

import org.droid3d.math.Float3;
import org.droid3d.renderer.buffer.VertexBuffer;
import org.droid3d.scenegraph.BoundingVolume;
import org.droid3d.scenegraph.Transformation;
import org.droid3d.utils.buffer.Channel;
import org.droid3d.utils.buffer.ChannelFactory;

public class BoundingVolumes {
	public static BoundingVolume computeFrom(VertexBuffer vertexBuffer) {
		Float3 center = new Float3();
		float radius = 0f;

		Channel<Float3> positionAdapter = ChannelFactory.newPositionChannel(vertexBuffer);
		if (positionAdapter != null) {
			int vertexCount = positionAdapter.getElementCount();
			for (int i = 0; i < vertexCount; i++) {
				center.add(positionAdapter.read(i));
			}
			center.mult(1f / vertexCount);

			for (int i = 0; i < vertexCount; i++) {
				Float3 diff = positionAdapter.read(i);
				diff.sub(center);
				float rSqr = diff.getSquaredLength();
				if (rSqr > radius) {
					radius = rSqr;
				}
			}
			radius = (float) Math.sqrt(radius);
		}

		return new BoundingVolume(center, radius);
	}

	public static BoundingVolume transform(BoundingVolume bv, Transformation t) {
		BoundingVolume transBV = new BoundingVolume();
		transBV.setCenter(t.applyForward(bv.getCenter()));
		transBV.setRadius(t.getNorm() * bv.getRadius());
		return transBV;
	}
}
