/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.utils;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;

import org.apache.log4j.Logger;

import com.google.common.io.ByteStreams;
import com.google.common.io.CharStreams;

public class IOUtils {
	private static final Logger	LOG	= Logger.getLogger(IOUtils.class);

	public static byte[] loadFile(String filename) {
		return loadFile(IOUtils.class.getResource(filename));
	}

	public static byte[] loadFile(URL url) {
		byte[] bytes = null;
		if (url != null) {
			InputStream in = null;
			try {
				in = url.openStream();
				bytes = ByteStreams.toByteArray(in);
			} catch (IOException e) {
				LOG.error(String.format("Error loading file '%s':", url), e);
			} finally {
				if (in != null) {
					try {
						in.close();
					} catch (IOException e2) {
						LOG.warn(
								String.format("Could not close file '%s'", url),
								e2);
					}
				}
			}
		}
		return bytes;
	}

	/**
	 * Load a text file.
	 * 
	 * @param filename
	 * @return
	 */
	public static String loadTextFile(String filename) {
		return loadTextFile(IOUtils.class.getResource(filename));
	}

	public static String loadTextFile(URL url) {
		String str = null;
		if (url != null) {
			InputStreamReader in = null;
			try {
				in = new InputStreamReader(url.openStream());
				str = CharStreams.toString(in);
			} catch (IOException e) {
				LOG.error(String.format("Error loading text file '%s':", url),
						e);
			} finally {
				if (in != null) {
					try {
						in.close();
					} catch (IOException e2) {
						LOG.warn(
								String.format("Could not close file '%s'", url),
								e2);
					}
				}
			}
		}
		return str;
	}
}
