package org.droid3d.utils;

public enum Type {
//@formatter:off
	UNSIGNED_BYTE,
	UNSIGNED_SHORT,
	SHORT,
	INT, 
	FLOAT, FLOAT2, FLOAT3, FLOAT4,
	MAT22, MAT33, MAT44,
	COLOR;	// @formatter:on

	public static final int	SIZE_OF_UNSIGNED_BYTE	= 1;
	public static final int	SIZE_OF_UNSIGNED_SHORT	= 2;
	public static final int	SIZE_OF_SHORT			= 2;
	public static final int	SIZE_OF_INT				= 4;

	public static final int	SIZE_OF_FLOAT			= 4;
	public static final int	SIZE_OF_FLOAT2			= 2 * SIZE_OF_FLOAT;
	public static final int	SIZE_OF_FLOAT3			= 3 * SIZE_OF_FLOAT;
	public static final int	SIZE_OF_FLOAT4			= 4 * SIZE_OF_FLOAT;

	public static final int	SIZE_OF_MAT22			= 4 * SIZE_OF_FLOAT;
	public static final int	SIZE_OF_MAT33			= 9 * SIZE_OF_FLOAT;
	public static final int	SIZE_OF_MAT44			= 16 * SIZE_OF_FLOAT;

	public static final int	SIZE_OF_COLOR			= 4 * SIZE_OF_FLOAT;

	public int getPrimitiveCount() {
		switch (this) {
		case UNSIGNED_BYTE:
		case UNSIGNED_SHORT:
		case SHORT:
		case INT:
		case FLOAT:
			return 1;
		case FLOAT2:
			return 2;
		case FLOAT3:
			return 3;
		case FLOAT4:
		case MAT22:
		case COLOR:
			return 4;
		case MAT33:
			return 9;
		case MAT44:
			return 16;
		default:
			throw new UnsupportedOperationException();
		}
	}

	public Type getPrimitiveType() {
		switch (this) {
		case UNSIGNED_SHORT:
			return UNSIGNED_SHORT;
		case SHORT:
			return SHORT;
		case INT:
			return INT;
		default:
			return FLOAT;
		}
	}

	public boolean isPrimitive() {
		return this == SHORT || this == INT || this == FLOAT || this == UNSIGNED_SHORT;
	}

	public int size() {
		switch (this) {
		case UNSIGNED_BYTE:
			return SIZE_OF_UNSIGNED_BYTE;
		case UNSIGNED_SHORT:
		case SHORT:
			return SIZE_OF_SHORT;
		case INT:
			return SIZE_OF_INT;
		case FLOAT:
			return SIZE_OF_FLOAT;
		case FLOAT2:
			return 2 * SIZE_OF_FLOAT;
		case FLOAT3:
			return 3 * SIZE_OF_FLOAT;
		case FLOAT4:
		case MAT22:
		case COLOR:
			return 4 * SIZE_OF_FLOAT;
		case MAT33:
			return 9 * SIZE_OF_FLOAT;
		case MAT44:
			return 16 * SIZE_OF_FLOAT;

		default:
			throw new UnsupportedOperationException();
		}
	}
}
