/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.utils.buffer;

import org.droid3d.renderer.buffer.Buffer;

/**
 * Implementing classes provide a way to read/write values of a buffer.
 * 
 * @param <T>
 */
public interface Channel<T> {
	/**
	 * Get the buffer.
	 * 
	 * @return
	 */
	Buffer getBuffer();

	/**
	 * Get the number of elements in the buffer.
	 * 
	 * @return
	 */
	int getElementCount();

	/**
	 * Read a value.
	 * 
	 * @param position
	 *            position of the buffer to read from
	 * @return
	 */
	T read(int position);

	/**
	 * Read a value.
	 * 
	 * @param position
	 *            position of the buffer to read from
	 * @param value
	 * @return
	 */
	T read(int position, T value);

	/**
	 * Set the buffer.
	 * 
	 * @param buffer
	 */
	void setBuffer(Buffer buffer);

	/**
	 * Write a value.
	 * 
	 * @param position
	 *            position of the buffer to write to
	 * @param value
	 */
	void write(int position, T value);
}
