/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.utils.buffer;

import org.droid3d.math.Float2;
import org.droid3d.math.Float3;
import org.droid3d.renderer.Color;
import org.droid3d.renderer.buffer.VertexAttribute;
import org.droid3d.renderer.buffer.VertexBuffer;

public class ChannelFactory {
	public static Channel<Color> newColorChannel(VertexBuffer vertexBuffer) {
		Channel<Color> adapter = null;
		VertexAttribute colorAttr = vertexBuffer.getAttribute(VertexAttribute.Usage.Color);
		if (colorAttr != null) {
			adapter = new VertexBufferChannel<Color>(vertexBuffer, colorAttr, new ColorChannel(vertexBuffer));
		}
		return adapter;
	}

	public static Channel<Float2> newTexCoordChannel(VertexBuffer vertexBuffer) {
		return newChannel(vertexBuffer, VertexAttribute.Usage.TexCoord, new Float2Channel());
	}

	public static <T> Channel<T> newChannel(VertexBuffer vertexBuffer, VertexAttribute.Usage vertexUsage,
			Channel<T> channel) {
		Channel<T> adapter = null;
		VertexAttribute attr = vertexBuffer.getVertexDescriptor().getAttribute(VertexAttribute.Usage.TexCoord);
		if (attr != null) {
			adapter = new VertexBufferChannel<T>(vertexBuffer, attr, channel);
		}
		return adapter;
	}

	public static Channel<Float3> newNormalChannel(VertexBuffer vertexBuffer) {

		Channel<Float3> adapter = null;
		VertexAttribute attr = vertexBuffer.getVertexDescriptor().getAttribute(VertexAttribute.Usage.Normal);
		if (attr != null) {
			adapter = new VertexBufferChannel<Float3>(vertexBuffer, attr, new Float3Channel());
		}
		return adapter;
	}

	public static Channel<Float3> newPositionChannel(VertexBuffer vertexBuffer) {
		Channel<Float3> adapter = null;
		VertexAttribute attr = vertexBuffer.getVertexDescriptor().getAttribute(VertexAttribute.Usage.Position);
		if (attr != null) {
			adapter = new VertexBufferChannel<Float3>(vertexBuffer, attr, new Float3Channel());
		}
		return adapter;
	}

}
