/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.utils.buffer;

import org.droid3d.math.Float2;
import org.droid3d.renderer.buffer.Buffer;
import org.droid3d.utils.Type;

public class Float2Channel extends AbstractChannel<Float2> {
	public Float2Channel() {
	}

	public Float2Channel(Buffer buffer) {
		super(buffer);
	}

	@Override
	public int getElementCount() {
		return mBuffer.getData().capacity() / Type.SIZE_OF_FLOAT2;
	}

	@Override
	public Float2 read(int position) {
		return read(position, new Float2());
	}

	@Override
	public Float2 read(int position, Float2 value) {
		float[] tmp = new float[2];
		mBuffer.getFloat(position, tmp);
		value.load(tmp);
		return value;
	}

	@Override
	public void write(int position, Float2 value) {
		mBuffer.putFloat(position, value.x, value.y);
	}

}
