/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.utils.buffer;

import org.droid3d.math.Float3;
import org.droid3d.renderer.buffer.Buffer;

/**
 * An adapter to read or write Vector3F from/to a buffer.
 */
public class Float3Channel extends AbstractChannel<Float3> {
	public Float3Channel() {
	}

	public Float3Channel(Buffer buffer) {
		super(buffer);
	}

	@Override
	public int getElementCount() {
		return mBuffer.getData().capacity() / 12;
	}

	@Override
	public Float3 read(int element) {
		return read(element, new Float3());
	}

	@Override
	public Float3 read(int element, Float3 value) {
		float[] tmp = new float[3];
		mBuffer.getFloat(element, tmp);
		value.load(tmp);
		return value;
	}

	@Override
	public void write(int element, Float3 value) {
		mBuffer.putFloat(element, value.toArray());
	}

}
