/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.utils.buffer;

import org.droid3d.renderer.buffer.VertexAttribute;
import org.droid3d.utils.Type;

/**
 * A factory that creates {@link VertexAttribute}s for various built-in types.
 */
public class VertexAttributeFactory {

	/**
	 * The default name of a position attribute.
	 */
	public static final String	DEFAULT_ATTR_NAME_POSITION	= "inPosition";
	/**
	 * The default name of a color attribute.
	 */
	public static final String	DEFAULT_ATTR_NAME_COLOR		= "inColor";
	/**
	 * The default name of a normal attribute.
	 */
	public static final String	DEFAULT_ATTR_NAME_NORMAL	= "inNormal";

	public static final String	DEFAULT_ATTR_NAME_TEXCOORD	= "inTexCoord";

	public static VertexAttribute newColorAttr() {
		return newColorAttr(DEFAULT_ATTR_NAME_COLOR);
	}

	public static VertexAttribute newColorAttr(String name) {
		return newFloat4Attr(name, VertexAttribute.Usage.Color);
	}

	public static VertexAttribute newFloatAttr(String name,
			int elementCount, VertexAttribute.Usage usage) {
		return new VertexAttribute(name, Type.FLOAT, elementCount, usage);
	}

	public static VertexAttribute newMatrix33Attr(String name) {
		return new VertexAttribute(name, Type.FLOAT, 9);
	}

	public static VertexAttribute newMatrix44Attr(String name) {
		return new VertexAttribute(name, Type.FLOAT, 16);
	}

	public static VertexAttribute newNormalAttr() {
		return newFloat3Attr(DEFAULT_ATTR_NAME_NORMAL,
				VertexAttribute.Usage.Normal);
	}

	public static VertexAttribute newPositionAttr() {
		return newFloat3Attr(DEFAULT_ATTR_NAME_POSITION,
				VertexAttribute.Usage.Position);
	}

	public static VertexAttribute newPositionAttr(String name) {
		return newFloat3Attr(name, VertexAttribute.Usage.Position);
	}

	public static VertexAttribute newTexCoordAttr() {
		return new VertexAttribute(DEFAULT_ATTR_NAME_TEXCOORD, Type.FLOAT, 2,
				VertexAttribute.Usage.TexCoord);
	}

	public static VertexAttribute newFloat2Attr(String name,
			VertexAttribute.Usage usage) {
		return new VertexAttribute(name, Type.FLOAT, 2, usage);
	}

	public static VertexAttribute newFloat3Attr(String name,
			VertexAttribute.Usage usage) {
		return new VertexAttribute(name, Type.FLOAT, 3, usage);
	}

	public static VertexAttribute newFloat4Attr(String name) {
		return newFloat4Attr(name, VertexAttribute.Usage.Generic);
	}

	public static VertexAttribute newFloat4Attr(String name,
			VertexAttribute.Usage usage) {
		return new VertexAttribute(name, Type.FLOAT, 4, usage);
	}

}
