/*******************************************************************************
 * Copyright 2013 Bo Meier (bo.meier@gmail.com)
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.droid3d.utils.buffer;

import org.droid3d.renderer.buffer.Buffer;
import org.droid3d.renderer.buffer.VertexAttribute;
import org.droid3d.renderer.buffer.VertexBuffer;

public class VertexBufferChannel<T> implements Channel<T> {
	private Channel<T>	mAdapter;
	private int			mOffset;
	private int			mStride;
	private int			mElementCount;

	public VertexBufferChannel(VertexBuffer buffer, int attributeIdx, Channel<T> adapter) {
		this(buffer, buffer.getAttribute(attributeIdx), adapter);
	}

	public VertexBufferChannel(VertexBuffer buffer, String attribute, Channel<T> adapter) {
		this(buffer, buffer.getAttribute(attribute), adapter);
	}

	public VertexBufferChannel(VertexBuffer buffer, VertexAttribute attribute, Channel<T> adapter) {
		mAdapter = adapter;
		mOffset = buffer.getOffset(attribute);
		mStride = buffer.getVertexSize();
		mElementCount = buffer.getVertexCount();
		setBuffer(buffer);
	}

	@Override
	public Buffer getBuffer() {
		return mAdapter.getBuffer();
	}

	@Override
	public int getElementCount() {
		return mElementCount;
	}

	@Override
	public final T read(int element) {
		return mAdapter.read(mOffset + element * mStride);
	}

	@Override
	public T read(int element, T value) {
		return mAdapter.read(element, value);
	}

	@Override
	public void setBuffer(Buffer buffer) {
		mAdapter.setBuffer(buffer);
	}

	@Override
	public final void write(int element, T value) {
		mAdapter.write(mOffset + element * mStride, value);
	}
}
